@@ -4,11 +4,11 @@
 # Licenced under GPLv2
 
 #################################################################
-##   swappolube  -  Configuration UI for the swappolube script ##
+##  swappolube  -  Configuration UI for the swappolube script  ##
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '0.3-3'
+Version = '0.3-4'
 
 import os
 import sys
@@ -28,7 +28,6 @@ DefaultFile  = 'swappolube_config_default'    # name of default config file
 MainPath     = '/etc/event.d/'                # main path
 MainFile     = 'tuning'                       # tuning file
 
-
 ##############################################################
 
 def CheckFile(Path, File):
@@ -190,9 +189,14 @@ class MyMainWindow(QtGui.QMainWindow):
         def doAbout(self):
           self.aboutWin = SwappolubeAbout(self)
 
-        def doDeleteTunings(self): ##FIXME: check if file was deleted!!
+        def doDeleteTunings(self):
              os.system('sudo %supdateTuning deleteTuning' % AppPath)
-             message = 'The tuning file has been removed from the boot sequence.\nOn next reboot, the system will start with its default configuration.'
+             if CheckFile(MainPath, MainFile) == True:
+                message = 'The tuning file could not be deleted.\
+                           \nPlease delete it manually.'
+             else: 
+                message = 'The tuning file has been removed from the boot sequence.\
+                           \nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
 
         def doRestoreDefault(self):
@@ -214,7 +218,11 @@ class MyMainWindow(QtGui.QMainWindow):
              os.system('sudo %supdateTuning DirtyBGDRatio 10' % AppPath )
              os.system('sudo %supdateTuning VFSCachePressure 100' % AppPath )
              
-             message = 'The default configuration has been applied to the system.'
+             if CheckFile(MainPath, MainFile) == True:
+                message = 'The default values have been restored to the system.\
+                           \n\nWARNING: A tuning file exists and will reapply its settings on the next reboot.'
+             else:   
+                message = 'The default values have been restored to the system.'
              showMessage(message)
              
              ##Set current values in the GUI
@@ -361,7 +369,10 @@ class MyMainWindow(QtGui.QMainWindow):
                os.system('sudo %supdateTuning DirtyBGDRatio %s' % (AppPath, DirtyBGDRatio) )
              if self.ui.radioVFSCachePressure.isChecked() == True:
                os.system('sudo %supdateTuning VFSCachePressure %s' % (AppPath, VFSCachePressure) )
-             message = 'The new configuration has been applied to the system.'
+
+             message = 'The new configuration has been applied to the system.\
+                        These settings will be changed back to its defaults on the next reboot.\
+                        \n\nIf you want them to persist use the "Store" button.'
              showMessage(message)
              
         def doCreateConfig(self):
